Enum sp_im::ordmap::DiffItem [−][src]
pub enum DiffItem<'a, K, V> {
Add(&'a K, &'a V),
Update {
old: (&'a K, &'a V),
new: (&'a K, &'a V),
},
Remove(&'a K, &'a V),
}Expand description
A description of a difference between two ordered maps.
Variants
This value has been added to the new map.
This value has been changed between the two maps.
This value has been removed from the new map.