pub struct VacantEntry<'a, K, V> where
K: Ord + Clone,
V: Clone, { /* fields omitted */ }
An entry for a mapping that does not already exist in the map.
Get the key for this entry.
Convert this entry into its key.
Insert a value into this entry.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Get a new Arc pointer for this value
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.