Enum sp_im::ordset::DiffItem[][src]

pub enum DiffItem<'a, A> {
    Add(&'a A),
    Update {
        old: &'a A,
        new: &'a A,
    },
    Remove(&'a A),
}
A description of a difference between two ordered sets.

Variants

Add(&'a A)

This value has been added to the new set.

Tuple Fields of Add

0: &'a A
Update

This value has been changed between the two sets.

Fields of Update

old: &'a A

The old value.

new: &'a A

The new value.

Remove(&'a A)

This value has been removed from the new set.

Tuple Fields of Remove

0: &'a A