Struct sp_im::vector::RRBPool[][src]

pub struct RRBPool<A> { /* fields omitted */ }
A memory pool for Vector.

Implementations

Create a new memory pool with the given size.

Create a new memory pool with the given sizes for each subpool.

Fill the memory pool with preallocated chunks.

Get the size of the node subpool.

Get the size of the leaf node subpool.

Get the size of the size table subpool.