Struct sp_im::ordmap::OccupiedEntry[][src]

pub struct OccupiedEntry<'a, K, V> where
    K: Ord + Clone,
    V: Clone
{ /* fields omitted */ }
An entry for a mapping that already exists in the map.

Implementations

Get the key for this entry.

pub fn remove_entry(self) -> (K, V)

Remove this entry from the map and return the removed mapping.

Get the current value.

Get a mutable reference to the current value.

Convert this entry into a mutable reference.

Overwrite the current value.

Remove this entry from the map and return the removed value.