pub struct OccupiedEntry<'a, K, V> where
K: Ord + Clone,
V: Clone, { /* fields omitted */ }
An entry for a mapping that already exists in the map.
Get the key for this entry.
Remove this entry from the map and return the removed mapping.
Get a mutable reference to the current value.
Convert this entry into a mutable reference.
Overwrite the current value.
Remove this entry from the map and return the removed value.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
Get a new Arc pointer for this value
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.